﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using Telerik.Windows.Documents;
using Telerik.Windows.Controls;
using Telerik.Windows.Documents.TextSearch;
using System.IO;
using Telerik.Windows.Documents.Layout;
using Telerik.Windows.Documents.FormatProviders;
using Telerik.Windows.Documents.Model;
using System.Reflection;

namespace BookRichTextBoxIntegration
{
	public partial class MainPage : UserControl
	{

		private RadDocumentBindingSource bindingSource = new RadDocumentBindingSource();
		private DocumentViewManager viewManager;

		public MainPage()
		{
			InitializeComponent();

			this.viewManager = (DocumentViewManager)this.Resources["viewManager"];
		}

		private void LoadDocument(Stream stream, string extension)
		{
			RadDocument doc;

			IDocumentFormatProvider provider = DocumentFormatProvidersManager.GetProviderByExtension(extension);
			if (provider != null)
			{
				doc = provider.Import(stream);
			}
			else
			{
				MessageBox.Show("Unknown format.");
				return;
			}

			doc.Measure(RadDocument.MAX_DOCUMENT_SIZE);
			doc.Arrange(new RectangleF(PointF.Empty, doc.DesiredSize));

			doc.LayoutMode = DocumentLayoutMode.Paged;

			doc.DefaultPageLayoutSettings.Width = 320 / 0.7F;
			doc.DefaultPageLayoutSettings.Height = 390 / 0.7F;
			doc.SectionDefaultPageMargin = new Padding(55);
			doc.Sections.First.PageMargin = new Padding(55);

			doc.UpdateLayout();

			this.book.RightPageIndex = 0;

			this.viewManager.Document = doc;
			bindingSource.Document = doc;
			this.book.ItemsSource = bindingSource;
		}

		private Uri GetResourceUri(string resource)
		{
			AssemblyName assemblyName = new AssemblyName(this.GetType().Assembly.FullName);
			string resourcePath = "/" + assemblyName.Name + ";component/" + resource;
			Uri resourceUri = new Uri(resourcePath, UriKind.Relative);

			return resourceUri;
		}

		private void buttonOpen_Click(object sender, RoutedEventArgs e)
		{
			OpenFileDialog ofd = new OpenFileDialog();
			ofd.Filter = "Word Documents (*.docx)|*.docx|Web Pages (*.htm,*.html)|*.htm;*.html|Rich Text Format (*.rtf)|*.rtf|Text Files (*.txt)|*.txt|XAML Files (*.xaml)|*.xaml";

			if (ofd.ShowDialog() == true)
			{
				Stream stream;
				stream = ofd.File.OpenRead();

				using (stream)
				{
					string extension;
					extension = ofd.File.Extension;

					this.LoadDocument(stream, extension);
				}
			}
		}

		private void btnSearch_Click(object sender, RoutedEventArgs e)
		{
			this.Search();
		}

		private void tbSearchText_KeyDown(object sender, KeyEventArgs e)
		{
			if (e.Key == Key.Enter)
			{
				this.Search();
			}
		}

		private void Search()
		{
			DocumentTextSearch search = new DocumentTextSearch(this.viewManager.Document);

			SearchWindow searchWindow = new SearchWindow();

			searchWindow.Opacity = 0.9;
			searchWindow.WindowStartupLocation = Telerik.Windows.Controls.WindowStartupLocation.CenterScreen;

			searchWindow.LoadFoundItems(this.book, this.viewManager.Document, search.FindAll(this.tbSearchText.Text));
			searchWindow.ModalBackground = new SolidColorBrush(Colors.Transparent);
			searchWindow.ShowDialog();
		}
	}
}
