﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using Telerik.Windows.Controls;
using Telerik.Windows.Documents.Model;
using Telerik.Windows.Input;
using Telerik.Windows.Documents.TextSearch;
using Telerik.Windows.Documents;
using Telerik.Windows.Documents.Selection;

namespace BookRichTextBoxIntegration
{
	public partial class SearchWindow : RadWindow
	{
		private RadDocument document;
		private RadBook book;

		public SearchWindow()
		{
			InitializeComponent();

			this.Init();
		}
		private void Init()
		{
			Mouse.AddMouseUpHandler(this.lbFoundItems, this.ListBoxMouseUp);
		}

		private void btnClose_Click(object sender, RoutedEventArgs e)
		{
			this.Close();
		}

		public void LoadFoundItems(RadBook book, RadDocument document, IEnumerable<TextRange> items)
		{
			this.book = book;
			this.document = document;
			foreach (TextRange textRange in items)
			{
				TextBlock block = GetFoundTextBlock(textRange);

				System.Windows.Controls.ListBoxItem listBoxItem = new System.Windows.Controls.ListBoxItem();
				listBoxItem.Content = block;
				listBoxItem.Tag = textRange;
				this.lbFoundItems.Items.Add(listBoxItem);
			}

			ItemCollection listboxItems = this.lbFoundItems.Items;
			int itemsCount = listboxItems.Count;

			if (itemsCount == 0)
			{
				this.lbFoundItems.Visibility = System.Windows.Visibility.Collapsed;
			}
			else
			{
				this.Header = string.Format("Search Results: {0} occurrence(s) found", itemsCount);
				this.lbFoundItems.Visibility = System.Windows.Visibility.Visible;
			}
		}

		private TextBlock GetFoundTextBlock(TextRange textRange)
		{
			TextBlock block = new TextBlock();

			DocumentPosition pos = new DocumentPosition(textRange.StartPosition);
			pos.MoveToCurrentLineStart();
			DocumentPosition pos1 = new DocumentPosition(textRange.EndPosition);
			pos1.MoveToCurrentLineEnd();
			DocumentSelection selection = new DocumentSelection(this.document);
			selection.SetSelectionStart(pos);
			selection.AddSelectionEnd(pos1);

			System.Windows.Documents.Run run = new System.Windows.Documents.Run();
			run.Text = string.Format("...{0}...", selection.GetSelectedText());
			run.TextDecorations = TextDecorations.Underline;
			block.Inlines.Add(run);
			run = new System.Windows.Documents.Run();
			run.Foreground = new SolidColorBrush(Colors.Blue);
			run.TextDecorations = TextDecorations.Underline;
			run.Text = string.Format("On page {0}. ", textRange.StartPosition.GetCurrentSectionBox().ChildIndex + 1);
			block.Inlines.Add(run);
			block.TextWrapping = TextWrapping.Wrap;
			return block;
		}

		private void ListBoxMouseUp(object sender, Telerik.Windows.Input.MouseButtonEventArgs args)
		{
			if (this.lbFoundItems.SelectedIndex >= 0)
			{
				TextRange textRange = ((System.Windows.Controls.ListBoxItem)this.lbFoundItems.SelectedItem).Tag as TextRange;
				if (textRange != null)
				{
					int pageIndex = textRange.StartPosition.GetCurrentSectionBox().ChildIndex;
					if (pageIndex % 2 == 0)
					{
						book.RightPageIndex = pageIndex;
					}
					else
					{
						book.RightPageIndex = pageIndex - 1;
					}

					textRange.SetSelection(this.document);
				}
			}
		}
	}
}


